@@ -8,7 +8,7 @@
 #' @export
 #' @return Vector of lenght 6: c(x_min, x_max, y_min, y_max, eps, pen). Limits are given in UTM coordinates.
 #' @example man/examples/example-bbox.R
-getBbox <- function(hydros, buffer=5, eps=1E-3, pen=1){
+getBbox <- function(hydros, buffer=100, eps=1E-3, pen=1E6){
 	x_min <- hydros[which.min(hydros$hx), hx] - buffer
 	x_max <- hydros[which.max(hydros$hx), hx] + buffer
 	y_min <- hydros[which.min(hydros$hy), hy] - buffer
