@@ -7,10 +7,10 @@ plotBbox <- function(hydros, bbox){
 	Var1 <- Var2 <- NULL
 	softplus <- function(x, eps){return (0.5*(x+sqrt(x*x+eps*eps)))	}
 
-	x_space_min <- floor(hydros[which.min(hydros$hx), hx] - 20)
-	x_space_max <- ceiling(hydros[which.max(hydros$hx), hx] + 20)
-	y_space_min <- floor(hydros[which.min(hydros$hy), hy] - 20)
-	y_space_max <- ceiling(hydros[which.max(hydros$hy), hy] + 20)
+	x_space_min <- floor(hydros[which.min(hydros$hx), hx] - 100)
+	x_space_max <- ceiling(hydros[which.max(hydros$hx), hx] + 100)
+	y_space_min <- floor(hydros[which.min(hydros$hy), hy] - 100)
+	y_space_max <- ceiling(hydros[which.max(hydros$hy), hy] + 100)
 	
 	xs <- x_space_min:x_space_max
 	ys <- y_space_min:y_space_max
@@ -33,7 +33,10 @@ plotBbox <- function(hydros, bbox){
 	pen_long[, y := ys[Var2]]
 	pen_long[, pen := value]
 
-	p <- ggplot2::ggplot(pen_long) + geom_tile(aes(x, y, fill=(pen))) + coord_fixed(ratio=1) + viridis::scale_fill_viridis() + geom_point(data=hydros, aes(x=hx, y=hy), col="red", size=2)
+	p <- ggplot2::ggplot(pen_long) + geom_tile(aes(x, y, fill=log(pen))) + 
+		coord_fixed(ratio=1, xlim=range(c(xs, x_min, x_max)), ylim=range(c(ys, y_min, y_max))) + 
+		viridis::scale_fill_viridis() + 
+		geom_point(data=hydros, aes(x=hx, y=hy), col="red", size=2)
 	print(p)
 }
 
