@@ -3,9 +3,11 @@
 
 	PARAMETER(logScale);		// scale-parameter for t-dist
 	Type scale = exp(logScale);
+	// nll += dnorm(scale, Type(0), Type(25), true);
 
 	PARAMETER(log_t_part);		// t-part of mixture model 
-	Type t_part = exp(log_t_part);
+	// Type t_part = exp(log_t_part);
+	Type t_part = invlogit(log_t_part);
 	Type G_part = Type(1.0) - t_part; //Gaussian part of mixture model
 
 
@@ -14,6 +16,8 @@
 			if(!isNA(toa(h,i))){ //ignore NA's...
 				nll -= Edist(1) * log( G_part * dnorm(eps(h,i), Type(0),sigma_toa,false) + 		//Gaussian part
 					t_part * dt(eps(h,i)/scale, Type(3.0), false) );					//t part
+					// t_part * dt(eps(h,i)/scale, Type(3.0), false) / scale );					//t part
+					// t_part * dt(eps(h,i), Type(3.0), false));					//t part
 			}
 		}
 	}
